#!/bin/bash

#备份文件临时存放目录:数据
BACKUP_DIR_DATA="/tmp/gdrive/data"
#备份文件临时存放目录:文件
BACKUP_DIR_FILE="/tmp/gdrive/file"
#备份数据库,多个请空格分隔
MYSQL_DBS=""
#备份目录,多个请空格分隔
BACKUP_SRC=""
#备份文件压缩密码确保压缩包的安全
BACKUP_FILE_PASSWD=""
#MYSQL用户
mysql_user="root"
#MYSQl用户密码
mysql_passwd=""
# please first edit /etc/my.cnf and add user and passwd to mysqldump, then set this parameter.
is_mysql_5_6="y"
# Delete old backup settings. All backups are kept at 0, and only one latest backup is kept at 1.
# 删除旧备份设置。0时保留所有备份，1时仅保留一个最新备份
delete_old_backup_settings="1"
# sql google drive code
sql_google_drive_code=""
# file google drive code
file_google_drive_code=""
#crontab
# 0 * * * * /bin/bash /root/backup.sh data
# 0 0 * * * /bin/bash /root/backup.sh file

#备份数据库
backup_data(){
	mkdir -p $BACKUP_DIR_DATA
	
	clear;echo "(1/4) $(date +"%H:%M:%S") 正在导出数据..."
	for db_name in $MYSQL_DBS
	do
		if [ "${is_mysql_5_6}" = "n" ];then
			mysqldump -u${mysql_user} -p${mysql_passwd} $db_name > "$BACKUP_DIR_DATA/$db_name.sql"
		else
			mysqldump $db_name > "$BACKUP_DIR_DATA/$db_name.sql"
		fi
	done
	
	echo "(2/4) $(date +"%H:%M:%S") 正在打包文件..."
	BACKUP_FILENAME="$(date +"%Y-%m-%d_%H:%M:%S").sql.zip"
	zip -q -r -P $BACKUP_FILE_PASSWD $BACKUP_DIR_DATA/$BACKUP_FILENAME $BACKUP_DIR_DATA/*.sql
	
	echo "(3/4) $(date +"%H:%M:%S") 正在上传文件..."
	gdrive upload $BACKUP_DIR_DATA/$BACKUP_FILENAME -p "${sql_google_drive_code}" | tee /root/upload.sql.log
	
	echo;echo "(4/4) $(date +"%H:%M:%S") 完成."
	rm -rf $BACKUP_DIR_DATA
}

#备份网站文件
backup_www_file(){
	mkdir -p $BACKUP_DIR_FILE
	
	clear;echo "(1/3) $(date +"%H:%M:%S") 正在打包文件..."
	BACKUP_FILENAME="$(date +"%Y-%m-%d_%H:%M:%S").www.zip"
	zip -q -r -P $BACKUP_FILE_PASSWD $BACKUP_DIR_FILE/$BACKUP_FILENAME $BACKUP_SRC
	
	echo "(2/3) $(date +"%H:%M:%S") 正在上传文件..."
	gdrive upload $BACKUP_DIR_FILE/$BACKUP_FILENAME -p "${file_google_drive_code}"  | tee /root/upload.www.log
	
	echo;echo "(3/3) $(date +"%H:%M:%S") 完成."
	rm -rf $BACKUP_DIR_FILE
}

delete_old_backup(){
	delete_old_sql(){
		if [ -e "/root/upload.sql.log" ];then
			sql_code=$(cat /root/upload.sql.log | grep Uploaded | awk '{print $2}')
			gdrive delete ${sql_code}
		fi
	}
	delete_old_www(){
		if [ -e "/root/upload.www.log" ];then
			www_code=$(cat /root/upload.www.log | grep Uploaded | awk '{print $2}')
			gdrive delete ${www_code}
		fi
	}

	option=$1
	if [[ ${delete_old_backup_settings} = "1" ]];then
		if [[ ${option} = "data" ]];then
			delete_old_sql
		elif [[ ${option} = "file" ]];then
			delete_old_www
		fi
	fi
}

command=$1

case "${command}" in
	data)
		delete_old_backup data
		backup_data;;
	file)
		delete_old_backup file
		backup_www_file;;
esac

#END 2019-07-31